#ifndef GLOBALS_H
#define GLOBALS_H

#define WILLEM_LIU "WillemLiu"
#define EASY_LIST "easylist"
#define LIST_TEXT "ListText"
#define LIST_NAMES "ListName"
#define SELECTED_LIST_NAME "SelectedListName"
#define DBUS_KEYBOARD_SLIDE "/org/freedesktop/Hal/devices/platform_slide"
#define CHECKED_ITEMS_TO_BOTTOM "CheckedItemsToBottom"
#define LANDSCAPE "Landscape"
#define PORTRAIT "Portrait"
#define AUTO_ORIENTATION "AutoOrientation"
#define LIST_TEXT "ListText"
#define SORT_A_Z "SortAlphabetically"
#define USERNAME "Username"
#define PASSWORD "Password"
#define SYNC_URL "SyncUrl"
#define DEFAULT_SYNC_URL "http://www.willemliu.nl/qt/maemo/easylist/getList.php"
#define SYNC_LIST_NAME "SyncList"

static const int BACK = 0;
static const int FORWARD = 1;

#endif // GLOBALS_H
